@@ -29,7 +29,7 @@
 #endif
 
 #define XSL_CONFIG_DIR DATADIR"/"
-#define NOT_ESCAPE "!\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[]^_`abcdefghijklmnopqrstuvwxyz{|}~"
+#define NOT_ESCAPE "!\"$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[]^_`abcdefghijklmnopqrstuvwxyz{|}~"
 
 
 #define REGEXP_PARAM "regexp"
